intelmq.bots.experts.taxonomy package — intelmq 3.0.0.alpha.1 documentation

# intelmq.bots.experts.taxonomy package

## Submodules

## intelmq.bots.experts.taxonomy.expert module

The mapping follows Reference Security Incident Taxonomy Working Group – RSIT WG https://github.com/enisaeu/Reference-Security-Incident-Taxonomy-Task-Force/ with extensions.

`intelmq.bots.experts.taxonomy.expert.` `BOT`

  alias of `intelmq.bots.experts.taxonomy.expert.TaxonomyExpertBot`

class `intelmq.bots.experts.taxonomy.expert.` `TaxonomyExpertBot`(bot_id: str, start: bool = False, sighup_event=None, disable_multithreading: Optional[bool] = None)

  Bases: `intelmq.lib.bot.Bot`

  Apply the eCSIRT Taxonomy to all events

  `process`()

## Module contents